@@ -41,7 +41,7 @@ class PDFALStarLearner:
         model_learned = False
         counter = 0
         counter_example_count = 0
-
+        last_size = 0
         while not model_learned:
             if verbose: print("*** Start Iter", counter, "***")
             counter += 1
@@ -55,6 +55,9 @@ class PDFALStarLearner:
 
             if verbose: print("Translating...")
             model = self.model_translator.translate(self.observation_table, self.terminal_symbol, self.comparator)
+            size = len(model.weighted_states)
+            assert size > last_size, 'Possible infinite loop'
+            last_size = size
             if verbose: print("Performing Equivalence Query...")
             model_learned, counterexample = self.perform_equivalence_query(model)
             if not model_learned:
